rebotics\_sdk.notifications package
===================================

Subpackages
-----------

.. toctree::

    rebotics_sdk.notifications.migrations

Submodules
----------

rebotics\_sdk.notifications.admin module
----------------------------------------

.. automodule:: rebotics_sdk.notifications.admin
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.apps module
---------------------------------------

.. automodule:: rebotics_sdk.notifications.apps
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.models module
-----------------------------------------

.. automodule:: rebotics_sdk.notifications.models
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.serializers module
----------------------------------------------

.. automodule:: rebotics_sdk.notifications.serializers
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.tasks module
----------------------------------------

.. automodule:: rebotics_sdk.notifications.tasks
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.tests module
----------------------------------------

.. automodule:: rebotics_sdk.notifications.tests
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.urls module
---------------------------------------

.. automodule:: rebotics_sdk.notifications.urls
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.utils module
----------------------------------------

.. automodule:: rebotics_sdk.notifications.utils
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.notifications.views module
----------------------------------------

.. automodule:: rebotics_sdk.notifications.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rebotics_sdk.notifications
    :members:
    :undoc-members:
    :show-inheritance:
